/*
 * Tuxcall -- Call waiting detector for Linux
 * Copyright (C) 2001-2002 Angel Luis Jimenez Martinez
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */

#ifdef HAVE_CONFIG_H
#   include <config.h>
#endif

#include <intl.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "common.h"
#include "conf.h"

#define OPTLEN 50
#define VALUELEN 210
#define LINELEN (OPTLEN+VALUELEN)

#define COMMENT '#'

/*
 * Parses config line "line" (number "nLine"), storing option's name on "opt"
 * and value on "value"
 */
void parseLine( char * line, int nLine, char * opt, char * value )
{
    int i= 0, j;

    for( i=0; i<OPTLEN-1 && line[i]!='=' && line[i]!=0 && line[i]!=' '
              && line[i]!='\t'; i++ )
    {
        opt[i]= line[i];
    }

    opt[i]= 0;

    while( line[i]==' ' || line[i]=='\t' )
    {
        i++;
    }  

    if ( line[i] != '=' )
    {
        fprintf( stderr, _("Error: reading config file, line %d\n"), nLine ); 
        exit( -1 );
    }
    
    i++;
    while( line[i]==' ' || line[i]=='\t' )
    {
        i++;
    }

    for( j=i, i=0; line[j]!='\n' && line[j]!=0; i++, j++ )
    {
        value[i]= line[j];
    }
    value[i]= 0;
}

/*
 * Returns true if line is a valid config line (no comment, no white-line)
 */
int isValid( char * line )
{
    int i= 0;

    while( line[i]==' ' || line[i]=='\t' )
        i++;    

    return line[i] != COMMENT && line[i] != 0 && line[i]!= '\n';
}

/*
 * Reads TuxCall's config from fich
 */
void loadConfig( FILE * fich, char * device, char * hangCmd, float * freq
    , int * mode, float * limitMult )
{
    char opt[OPTLEN]
       , value[VALUELEN]
       , line[LINELEN];
    int nLine= 1;   
    char * chk;

    while( fgets( line, LINELEN-1, fich ) != NULL )
    {
        if ( isValid(line) )
        {
            parseLine( line, nLine, opt, value );

            if ( strcmp(opt, "frecuencia") == 0 )
            {
                *freq= strtod( value, &chk );
                if ( *freq==0 && value==chk )
                {
                    fprintf( stderr, _("Error: reading config file, line %d\n")
                        , nLine ); 
                    fprintf( stderr, _("Error: \"frecuencia\" must be a real number\n") );
                    exit( -1 );
                }

            }
            else if ( strcmp(opt, "limitmult") == 0 )
            {
                *limitMult= strtod( value, &chk );
                if ( *limitMult==0 && value==chk )
                {
                    fprintf( stderr, _("Error: reading config file, line %d\n")
                        , nLine ); 
                    fprintf( stderr, _("Error: \"limitmult\" must be a real number\n") );
                    exit( -1 );
                }

            }
            else if ( strcmp(opt, "comando") == 0 )
            {
                strncpy( hangCmd, value, CMDLEN );
            }
            else if ( strcmp(opt, "dispositivo") == 0 )
            {
                strncpy( device, value, FNAMELEN );
            }
            else if ( strcmp(opt, "modo") == 0 )
            {
                if ( strcmp( value, "EU" ) == 0)
                    *mode= EU;
                else if ( strcmp( value, "USA" ) == 0)
                    *mode= USA;
                else
                {
                    fprintf( stderr, _("Error: reading config file, line %d\n")
                        , nLine ); 
                    fprintf( stderr, _("Error: \"mode\" must be \"USA\" or \"EU\"\n") );
                    exit( -1 );
                }
            }
            else
            {
                fprintf( stderr, _("Error: reading config file, line %d\n")
                        , nLine ); 
                fprintf( stderr, _("Error: Unknown option \"%s\"\n"), opt );
                exit( -1 );
            }
        }

        nLine++;
    }
}

